Struct ViewportTextureHandle
pub struct ViewportTextureHandle(pub u64);Expand description
An opaque handle referencing a texture that the UI backend knows how to display.
Concrete backends (egui, etc.) map this to their own texture identifier. The handle is created by the render system when setting up an offscreen render target for the viewport.
Tuple Fields
0: u64Trait Implementations
impl Clone for ViewportTextureHandle
impl Clone for ViewportTextureHandle
fn clone(&self) -> ViewportTextureHandle
fn clone(&self) -> ViewportTextureHandle
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for ViewportTextureHandle
impl Debug for ViewportTextureHandle
impl Hash for ViewportTextureHandle
impl Hash for ViewportTextureHandle
impl PartialEq for ViewportTextureHandle
impl PartialEq for ViewportTextureHandle
fn eq(&self, other: &ViewportTextureHandle) -> bool
fn eq(&self, other: &ViewportTextureHandle) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for ViewportTextureHandle
impl Eq for ViewportTextureHandle
impl StructuralPartialEq for ViewportTextureHandle