GlobalTransform

Struct GlobalTransform 

pub struct GlobalTransform(pub AffineTransform);
A component that stores the final, calculated, world-space transformation of an entity.

This component’s value is the result of combining the entity’s local Transform with the GlobalTransform of its Parent, recursively up to the root of the scene.

It is intended to be read-only for most systems (like rendering and physics). It should only be written to by the dedicated transform propagation system. This acts as a cache to avoid re-calculating the full transform hierarchy every time it’s needed.

Tuple Fields

0: AffineTransform

Implementations



impl GlobalTransform

pub fn new(matrix: Mat4) -> GlobalTransform

Creates a new GlobalTransform from a Mat4.

pub fn identity() -> GlobalTransform

Creates a new identity GlobalTransform.

pub fn to_matrix(&self) -> Mat4

Returns the inner Mat4 representation.

pub fn at_position(position: Vec3) -> GlobalTransform

Creates a GlobalTransform representing a translation.