Transform

Struct Transform 

pub struct Transform {
    pub translation: Vec3,
    pub rotation: Quaternion,
    pub scale: Vec3,
}
A component that describes an entity’s position, rotation, and scale relative to its Parent. If the entity has no Parent, this is relative to the world origin.

This is the component that users and other systems should modify. A dedicated transform propagation system will use this component’s value to calculate the final GlobalTransform.

Fields

translation: Vec3

The translation (position) of the entity.

rotation: Quaternion

The rotation of the entity, represented as a quaternion.

scale: Vec3

The scale of the entity.

Implementations



impl Transform

pub fn new(translation: Vec3, rotation: Quaternion, scale: Vec3) -> Transform

Creates a new Transform with a given translation, rotation, and scale.

pub fn from_translation(translation: Vec3) -> Transform

Creates a new Transform with a given translation, and identity rotation/scale.

pub fn identity() -> Transform

Creates a new identity Transform, with no translation, rotation, or scaling. This represents the origin.

pub fn to_mat4(&self) -> Mat4

Calculates the Mat4 transformation matrix from this component’s translation, rotation, and scale.

The final matrix is calculated in the standard Scale -> Rotate -> Translate order.