pub enum CompareFunction {
Never,
Less,
Equal,
LessEqual,
Greater,
NotEqual,
GreaterEqual,
Always,
}Expand description
The comparison function used for depth and stencil testing.
Variants
Never
The test never passes.
Less
The test passes if the new value is less than the existing value.
Equal
The test passes if the new value is equal to the existing value.
LessEqual
The test passes if the new value is less than or equal to the existing value.
Greater
The test passes if the new value is greater than the existing value.
NotEqual
The test passes if the new value is not equal to the existing value.
GreaterEqual
The test passes if the new value is greater than or equal to the existing value.
Always
The test always passes.