pub enum TextureFormat {
Show 16 variants
R8Unorm,
Rg8Unorm,
Rgba8Unorm,
Rgba8UnormSrgb,
Bgra8UnormSrgb,
R16Float,
Rg16Float,
Rgba16Float,
R32Float,
Rg32Float,
Rgba32Float,
Depth16Unorm,
Depth24Plus,
Depth24PlusStencil8,
Depth32Float,
Depth32FloatStencil8,
}Expand description
Defines the memory format of pixels in a texture.
Variants
R8Unorm
One 8-bit unsigned normalized component.
Rg8Unorm
Two 8-bit unsigned normalized components.
Rgba8Unorm
Four 8-bit unsigned normalized components (RGBA).
Rgba8UnormSrgb
Four 8-bit unsigned normalized components (RGBA) in the sRGB color space.
Bgra8UnormSrgb
Four 8-bit unsigned normalized components (BGRA) in the sRGB color space. This is a common swapchain format.
R16Float
One 16-bit float component.
Rg16Float
Two 16-bit float components.
Rgba16Float
Four 16-bit float components.
R32Float
One 32-bit float component.
Rg32Float
Two 32-bit float components.
Rgba32Float
Four 32-bit float components.
Depth16Unorm
A 16-bit unsigned normalized depth format.
Depth24Plus
A 24-bit unsigned normalized depth format.
Depth24PlusStencil8
A 24-bit unsigned normalized depth format with an 8-bit stencil component.
Depth32Float
A 32-bit float depth format.
Depth32FloatStencil8
A 32-bit float depth format with an 8-bit stencil component.
Implementations
Sourceimpl TextureFormat
impl TextureFormat
Sourcepub fn bytes_per_pixel(&self) -> u32
pub fn bytes_per_pixel(&self) -> u32
Returns the size in bytes of a single pixel for this format. Note: This can be an approximation for packed or complex formats.