pub struct ShaderStage { /* private fields */ }Expand description
Flags representing which shader stages can access a resource binding.
This is used in bind group layouts to specify visibility of resources. Multiple stages can be combined using bitwise operations.
Implementations
Sourceimpl ShaderStageFlags
impl ShaderStageFlags
Sourcepub const NONE: ShaderStageFlags
pub const NONE: ShaderStageFlags
No shader stages.
Sourcepub const VERTEX: ShaderStageFlags
pub const VERTEX: ShaderStageFlags
Vertex shader stage.
Sourcepub const FRAGMENT: ShaderStageFlags
pub const FRAGMENT: ShaderStageFlags
Fragment shader stage.
Sourcepub const COMPUTE: ShaderStageFlags
pub const COMPUTE: ShaderStageFlags
Compute shader stage.
Sourcepub const VERTEX_FRAGMENT: ShaderStageFlags
pub const VERTEX_FRAGMENT: ShaderStageFlags
All graphics stages (vertex + fragment).
Sourcepub const ALL: ShaderStageFlags
pub const ALL: ShaderStageFlags
All stages.
Sourcepub const fn from_bits(bits: u32) -> ShaderStageFlags
pub const fn from_bits(bits: u32) -> ShaderStageFlags
Creates a new set of shader stage flags from raw bits.
Sourcepub const fn from_stage(stage: ShaderStage) -> ShaderStageFlags
pub const fn from_stage(stage: ShaderStage) -> ShaderStageFlags
Creates flags from a single shader stage.
Sourcepub const fn union(self, other: ShaderStageFlags) -> ShaderStageFlags
pub const fn union(self, other: ShaderStageFlags) -> ShaderStageFlags
Combines two sets of flags.
Sourcepub const fn contains(&self, stage: ShaderStage) -> bool
pub const fn contains(&self, stage: ShaderStage) -> bool
Checks if these flags contain a specific stage.