Struct SamplerDescriptor
pub struct SamplerDescriptor<'a> {
pub label: Option<Cow<'a, str>>,
pub address_mode_u: AddressMode,
pub address_mode_v: AddressMode,
pub address_mode_w: AddressMode,
pub mag_filter: FilterMode,
pub min_filter: FilterMode,
pub mipmap_filter: MipmapFilterMode,
pub lod_min_clamp: f32,
pub lod_max_clamp: f32,
pub compare: Option<CompareFunction>,
pub anisotropy_clamp: u16,
pub border_color: Option<SamplerBorderColor>,
}Expand description
A descriptor used to create a SamplerId.
A sampler defines how a shader will sample from a texture.
Fields
label: Option<Cow<'a, str>>An optional debug label.
address_mode_u: AddressModeThe address mode for the U (or S) texture coordinate.
address_mode_v: AddressModeThe address mode for the V (or T) texture coordinate.
address_mode_w: AddressModeThe address mode for the W (or R) texture coordinate.
mag_filter: FilterModeThe filter mode for magnification (when the texture is larger on screen than its resolution).
min_filter: FilterModeThe filter mode for minification (when the texture is smaller on screen than its resolution).
mipmap_filter: MipmapFilterModeThe filter mode to use between mipmap levels.
lod_min_clamp: f32The minimum level of detail (LOD) to use for mipmapping.
lod_max_clamp: f32The maximum level of detail (LOD) to use for mipmapping.
compare: Option<CompareFunction>If Some, creates a comparison sampler for tasks like shadow mapping.
anisotropy_clamp: u16The maximum anisotropy level to use.
border_color: Option<SamplerBorderColor>The border color to use if any address mode is ClampToBorder.