Struct TextureUsage
pub struct TextureUsage { /* private fields */ }Expand description
A set of flags describing the allowed usages of a TextureId.
Implementations
impl TextureUsage
impl TextureUsage
pub const EMPTY: TextureUsage
pub const EMPTY: TextureUsage
An empty set of flags.
pub const COPY_SRC: TextureUsage
pub const COPY_SRC: TextureUsage
The texture can be used as the source of a copy operation.
pub const COPY_DST: TextureUsage
pub const COPY_DST: TextureUsage
The texture can be used as the destination of a copy operation.
pub const TEXTURE_BINDING: TextureUsage
pub const TEXTURE_BINDING: TextureUsage
The texture can be bound in a shader for sampling (reading).
pub const STORAGE_BINDING: TextureUsage
pub const STORAGE_BINDING: TextureUsage
The texture can be used as a storage texture (read/write access from shaders).
pub const RENDER_ATTACHMENT: TextureUsage
pub const RENDER_ATTACHMENT: TextureUsage
The texture can be used as a color or multisample resolve attachment in a render pass.
pub const DEPTH_STENCIL_ATTACHMENT: TextureUsage
pub const DEPTH_STENCIL_ATTACHMENT: TextureUsage
The texture can be used as a depth/stencil target (for render attachments).
pub const fn from_bits_truncate(bits: u32) -> TextureUsage
pub const fn from_bits_truncate(bits: u32) -> TextureUsage
Creates a new bitflag set from the given raw bits. Bits not corresponding to any defined flag are kept.
pub const fn contains(&self, other: TextureUsage) -> bool
pub const fn contains(&self, other: TextureUsage) -> bool
Returns true if all flags in other are contained within self.
pub const fn intersects(&self, other: TextureUsage) -> bool
pub const fn intersects(&self, other: TextureUsage) -> bool
Returns true if any flag in other is contained within self.
pub fn insert(&mut self, other: TextureUsage)
pub fn insert(&mut self, other: TextureUsage)
Inserts the flags in other into self.
pub fn remove(&mut self, other: TextureUsage)
pub fn remove(&mut self, other: TextureUsage)
Removes the flags in other from self.
pub fn toggle(&mut self, other: TextureUsage)
pub fn toggle(&mut self, other: TextureUsage)
Toggles the flags in other in self.
pub const fn with(self, other: TextureUsage) -> TextureUsage
pub const fn with(self, other: TextureUsage) -> TextureUsage
Returns a new Self with other flags inserted.
pub const fn without(self, other: TextureUsage) -> TextureUsage
pub const fn without(self, other: TextureUsage) -> TextureUsage
Returns a new Self with other flags removed.