Struct CornerRadius
pub struct CornerRadius {
pub nw: f32,
pub ne: f32,
pub sw: f32,
pub se: f32,
}Expand description
Per-corner radius of a rounded rectangle, in logical pixels.
Backends that only support a single radius use the maximum of the
four corners (or nw if they’re all expected equal).
Fields
nw: f32North-west (top-left).
ne: f32North-east (top-right).
sw: f32South-west (bottom-left).
se: f32South-east (bottom-right).
Implementations
impl CornerRadius
impl CornerRadius
pub const ZERO: CornerRadius
pub const ZERO: CornerRadius
Square (no rounding).
pub const fn same(value: f32) -> CornerRadius
pub const fn same(value: f32) -> CornerRadius
All corners share value.