PhaseProvider

Trait PhaseProvider 

pub trait PhaseProvider {
    // Provided methods
    fn custom_phases(&self) -> Vec<ExecutionPhase> { ... }
    fn removed_phases(&self) -> Vec<ExecutionPhase> { ... }
}
Allows the application to add custom execution phases to the scheduler.

By default, the engine uses the standard phase order: OBSERVE → INPUT → TRANSFORM → SIMULATE → OUTPUT → PRESENT

Applications can insert custom phases (e.g. editor-specific phases).

Provided Methods

fn custom_phases(&self) -> Vec<ExecutionPhase>

Returns additional phases to insert into the scheduler’s phase order.

fn removed_phases(&self) -> Vec<ExecutionPhase>

Returns phases to remove from the default order.

Implementors