#[repr(C)]pub struct Vec3 {
pub x: f32,
pub y: f32,
pub z: f32,
}Expand description
A 3-dimensional vector with f32 components.
Fields
x: f32The x component of the vector.
y: f32The y component of the vector.
z: f32The z component of the vector.
Implementations
Sourceimpl Vec3
impl Vec3
Sourcepub const fn new(x: f32, y: f32, z: f32) -> Vec3
pub const fn new(x: f32, y: f32, z: f32) -> Vec3
Creates a new Vec3 with the specified components.
Sourcepub fn length_squared(&self) -> f32
pub fn length_squared(&self) -> f32
Calculates the squared length (magnitude) of the vector.
Sourcepub fn cross(&self, other: Vec3) -> Vec3
pub fn cross(&self, other: Vec3) -> Vec3
Computes the cross product of this vector and another.
Sourcepub fn distance_squared(&self, other: Vec3) -> f32
pub fn distance_squared(&self, other: Vec3) -> f32
Calculates the squared distance between this vector and another.
Sourcepub fn distance(&self, other: Vec3) -> f32
pub fn distance(&self, other: Vec3) -> f32
Calculates the distance between this vector and another.