pub trait AgentProvider {
// Required method
fn register_agents(&self, dcc: &DccService, runtime: &mut Runtime);
}Expand description
Allows the application to register custom agents with the DCC.
This is where mode-specific agents (like the editor’s UiAgent) are registered. The engine calls this method once during initialization, after the DCC is created.
Required Methods
Sourcefn register_agents(&self, dcc: &DccService, runtime: &mut Runtime)
fn register_agents(&self, dcc: &DccService, runtime: &mut Runtime)
Register agents with the DCC service.
Use dcc.register_agent(agent, priority) for agents active in all modes.
Use dcc.register_agent_for_mode(agent, priority, modes) for mode-specific agents.
The runtime bundle provides access to engine services / backends /
resources that agents may need.